def_macro

Function def_macro 

pub fn def_macro<T: Into<Option<ExpansionBody>>>(
    cs: Token,
    paramlist: Option<Parameters>,
    expansion: T,
    options_opt: Option<ExpandableOptions>,
) -> Result<()>
Defines the macro expansion for a command sequence.

A macro control sequence that reads parameters as specified by paramlist and is expanded during macro expansion time in the Gullet. See ExpansionBody for the possible kinds of expansion material.