def_math_primitive

Function def_math_primitive 

pub fn def_math_primitive(
    cs: Token,
    _paramlist: Option<Parameters>,
    presentation: String,
    options: MathPrimitiveOptions,
)
EXPERIMENT: Introduce an intermediate case for simple symbols Define a primitive that will create a Tbox with the appropriate set of XMTok attributes.